@@ -7,6 +7,7 @@
 #pragma once
 
 #include <QItemSelection>
+#include <QQmlEngine>
 #include <QSortFilterProxyModel>
 #include <QString>
 
@@ -17,10 +18,12 @@ class Entry;
 class AbstractEpisodeProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("")
 
 public:
     enum FilterType {
-        NoFilter,
+        NoFilter = 0,
         ReadFilter,
         NotReadFilter,
         NewFilter,
